//
// This work is licensed under the Creative Commons Attribution 2.5 License.
//
// To view a copy of this license, visit:
//   http://creativecommons.org/licenses/by/2.5/
//
// or send a letter to:
//   Creative Commons
//   543 Howard Street, 5th Floor
//   San Francisco, California, 94105, USA.
//
// All copies and derivatives of this source must contain the license statement 
// above and the following attribution:
//
// Author: Kyle Scholz      http://kylescholz.com/
// Copyright: 2006
//

/**
 * Seed DataGraph with contents of an XML tree structure.
 * 
 * @author Kyle Scholz
 * 
 * @version 0.3
 */
var WordNetLoader = function( dataGraph ) {
	this.http = new HTTP();
	this.subscribers = new Array();
	this.dataGraph = dataGraph;
}

/*
 * @param {Object} subscriber
 */
WordNetLoader.prototype.subscribe = function( subscriber ) {
	this.subscribers.push(subscriber);	
}

/*
 * 
 */
WordNetLoader.prototype.notify = function() {
	for( var i=0; i<this.subscribers.length; i++ ) {
		this.subscribers[i].notify();
	}
}

/*
 * Fetch XML data for processing
 */
WordNetLoader.prototype.load = function( url ) {
	this.http.get( url, this, this.handle );
}
	
/*
 * Process XML data in DataGraph.
 * 
 * @param {XMLHTTPRequest} request
 */
WordNetLoader.prototype.handle = function( request ) {
	var xmlDoc = request.responseXML;
	this.handleQuery(xmlDoc.documentElement);
}

/* Recursive node parser. Build a DataGraph to match XML tree.
 * 
 * @param {Object} xmlNode
 * @param {Object} parentNode
 */
WordNetLoader.prototype.handleNode = function(xmlNode,parentNode) {
	var dataNode = new DataGraphNode();
	dataNode.type = xmlNode.nodeName;
	if (parentNode) {
		dataNode.parent = parentNode;		
	} else {
		dataNode.root = true;
	}
	for( var i=0, l=xmlNode.attributes.length; i<l; i++ ) {
		dataNode[xmlNode.attributes[i].name]=xmlNode.attributes[i].value;
	}
	this.dataGraph.addNode( dataNode );	

	for( var i=0, l=xmlNode.childNodes.length; i<l; i++ ){
		if( childNodes[i].nodeName == "synset" ) {
			this.handleNode(childNodes[i],dataNode);
		}
	}
}