//
// This work is licensed under the Creative Commons Attribution 2.5 License.
//
// To view a copy of this license, visit:
//   http://creativecommons.org/licenses/by/2.5/
//
// or send a letter to:
//   Creative Commons
//   543 Howard Street, 5th Floor
//   San Francisco, California, 94105, USA.
//
// All copies and derivatives of this source must contain the license statement 
// above and the following attribution:
//
// Author: Kyle Scholz      http://kylescholz.com/
// Copyright: 2006
//

/**
 * Seed DataGraph with contents of an XML tree structure.
 * 
 * @author Kyle Scholz
 * 
 * @version 0.3
 */
var XMLTreeLoader = function( dataGraph ) {
	this.http = new HTTP();
	this.subscribers = new Array();
	this.dataGraph = dataGraph;
}

/*
 * @param {Object} subscriber
 */
XMLTreeLoader.prototype.subscribe = function( subscriber ) {
	this.subscribers.push(subscriber);	
}

/*
 * 
 */
XMLTreeLoader.prototype.notify = function() {
	for( var i=0; i<this.subscribers.length; i++ ) {
		this.subscribers[i].notify();
	}
}

/*
 * Fetch XML data for processing
 */
XMLTreeLoader.prototype.load = function( url ) {
	this.http.get( url, this, this.handle );
}
	
/*
 * Process XML data in DataGraph.
 * 
 * @param {XMLHTTPRequest} request
 */
XMLTreeLoader.prototype.handle = function( request ) {
	var xmlDoc = request.responseXML;
	var root = xmlDoc.getElementsByTagName("root")[0];

	// Add Root Node
	var rootNode = new DataGraphNode();
	for( var i=0, l=root.attributes.length; i<l; i++ ) {
		rootNode[root.attributes[i].name]=root.attributes[i].value;
	}
	this.dataGraph.addNode( rootNode );

	// Add children
	this.branch( root, rootNode );
	this.notify();
}

/*
 * @param {Object} root
 * @param {Object} rootNode
 */
XMLTreeLoader.prototype.branch = function( root, rootNode ) {
	var childNodes = root.childNodes;
	for( var i=0, l=childNodes.length; i<l; i++ ){
		if( childNodes[i].nodeName == "node" ) {
			var node = new DataGraphNode();
			node.parent = rootNode;
			for( var j=0, la=childNodes[i].attributes.length; j<la; j++ ) {
				node[childNodes[i].attributes[j].name]=childNodes[i].attributes[j].value;
			}
			this.dataGraph.addNode( node );
			
			this.branch( childNodes[i], node );
		}
	}
}